Version 2.0.0
-------------

**Features**
- added support for django 1.5
- added south as requirement, creating migrations is now possible


Version 1.0
-----------

Version 0.9.3
-------------

Version 0.9.2
-------------

Version 0.9.1
-------------

Version 0.9
-----------

Initial version